@@ -703,9 +703,11 @@ if(num.mode.x){
 			full.terms <- paste(nameslist,collapse = "*")
 			mod.formula <- as.formula(paste(fterms[nv0],"~",single.terms,"+",interaction.terms,sep=""))
 			
-			modS.formula <- as.formula(paste(fterms[nv0],"~",full.terms,sep=""))	
-			modS <- polr( formula = as.formula(modS.formula),data = dset, weights = dset$Freq, method ="logistic")
-			mod <- polr( formula = as.formula(mod.formula),data = dset, weights = dset$Freq, method ="logistic")
+			modS.formula <- as.formula(paste(fterms[nv0],"~",full.terms,sep=""))
+			if (requireNamespace("MASS", quietly = TRUE)) {	
+				modS <- MASS::polr( formula = as.formula(modS.formula),data = dset, weights = dset$Freq, method ="logistic")
+			mod <- MASS::polr( formula = as.formula(mod.formula),data = dset, weights = dset$Freq, method ="logistic")
+			}
 			pred <- predict(mod,newdata = subtable(dset,c(1:(nv-1)),keep.zero=F),type="probs")
 			fit.values <- as.vector(t(pred))
 			tt1r <- ftable(tapply(fit.values,as.list(dset[,1:nv]),sum),col.vars=which(col.vars))
